use crate::LinkKind;

#[derive(Debug, Default)]
pub struct Link {
    pub(crate) href: String,
    pub(crate) kind: LinkKind,
    pub(crate) title: Option<String>,
    plain: bool,
    dark: bool,
}

impl Link {
    pub fn current_tab(href: &str) -> Self {
        Link {
            href: href.to_owned(),
            ..Default::default()
        }
    }

    pub fn new_tab(href: &str) -> Self {
        Link {
            href: href.to_owned(),
            kind: LinkKind::NewTab,
            title: None,
            dark: false,
            plain: false,
        }
    }

    pub fn title(&mut self, title: &str) -> &mut Self {
        self.title = Some(title.to_owned());
        self
    }

    pub fn dark(&mut self, dark: bool) -> &mut Self {
        self.dark = dark;
        self
    }

    pub fn plain(&mut self, plain: bool) -> &mut Self {
        self.plain = plain;
        self
    }

    pub(crate) fn class_string(&self) -> String {
        let mut classes = vec!["toolkit-link"];

        if self.dark {
            classes.push("toolkit-dark");
        }
        if self.plain {
            classes.push("toolkit-plain");
        }

        classes.join(" ")
    }
}
